@@ -9,6 +9,8 @@ M2C_VERSION = 'v2'
 MOD = 'gopher'
 PROJECT_DIR = os.getcwd()
 GOPHER_DIR = os.path.join(PROJECT_DIR, MOD)
+APP_DIR = os.path.join(GOPHER_DIR, 'app')
+SERVICE_DIR = os.path.join(GOPHER_DIR, 'service')
 APIDOC_DIR = os.path.join(PROJECT_DIR, 'doc/api')
 M2C_PATH = os.path.join(PROJECT_DIR, '.m2c')
 BUILD_DIST = os.path.join(PROJECT_DIR, 'dist')
